[Telepathy-commits] [telepathy-gabble/master] Flush olpc info when a contact becomes unavailable

Sjoerd Simons sjoerd at luon.net
Tue Aug 19 10:54:08 PDT 2008


20080724114827-93b9a-47d6c814584e56f37c3acc8461049e6854656c32.gz
---
 src/conn-olpc.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/conn-olpc.c b/src/conn-olpc.c
index 9bf771a..52508da 100644
--- a/src/conn-olpc.c
+++ b/src/conn-olpc.c
@@ -2541,9 +2541,9 @@ connection_presence_do_update (GabblePresenceCache *cache,
 
   presence = gabble_presence_cache_get (cache, handle);
 
-  if (presence && presence->status == GABBLE_PRESENCE_OFFLINE)
+  if (presence && presence->status <= GABBLE_PRESENCE_LAST_UNAVAILABLE)
     {
       /* Contact goes offline. We have to unref all the information
        * provided by him
        */
       GPtrArray *empty = g_ptr_array_new ();
@@ -2541,9 +2541,9 @@ connection_presence_do_update (GabblePresenceCache *cache,
     {
-      /* Contact goes offline. We have to unref all the information
+      /* Contact becomes unavailable. We have to unref all the information
        * provided by him
        */
-- 
1.5.6.3




More information about the Telepathy-commits mailing list